==> media_twig_tools-2.0.0-rc3.tar.gz: media_twig_tools/src/Services/Bounce.php <==
<?php

namespace Drupal\media_twig_tools\Services;

use Drupal\Core\State\StateInterface;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Service description.
 */
class Bounce {

  /**
   * Service ID.
   *
   * @const string
   */
  public const SERVICE_ID = 'media_twig_tools.bounce';

  /**
   * State id.
   *
   * @const string
   */
  public const STATE_ID = 'media_twig_tools.bounce';

  /**
   * Singleton quick access.
   *
   * @return static
   *   Singleton.
   */
  public static function instance() {
    return \Drupal::service(static::SERVICE_ID);
  }

  /**
   * The state.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * Bounces.
   *
   * @var array
   */
  protected $bounces;

  /**
   * Dirname.
   *
   * @var string
   */
  protected $dirname;

  /**
   * Constructs a Bounce object.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The state.
   */
  public function __construct(StateInterface $state) {
    $this->state = $state;
  }

  /**
   * @return string
   */
  public function getDirname(): string {
    return $this->dirname;
  }

  /**
   * @param string $dirname
   */
  public function setDirname(string $dirname): void {
    $this->dirname = $dirname;
  }

  /**
   * Add the bounce in config.
   *
   * @param string $path
   *   The path.
   */
  public function addBounce(string $path) {
    $token = $this->getTokenFromPath($path);
    $bounces = $this->getBounces();
    if (!in_array($token, $bounces)) {
      $this->bounces[] = $token;
      $this->state->set(static::STATE_ID, $this->bounces);
    }
  }

  /**
   * Return token from path.
   *
   * @param string $path
   *   The file path.
   *
   * @return string
   *   The path.
   */
  public function getTokenFromPath(string $path) {
    $token = explode($this->getDirname(), $path);
    $token = end($token);
    $token = array_filter(explode('/', $token));
    return implode('/', array_slice($token, 0, -1));
  }

  /**
   * Check the bounce.
   *
   * @param string $path
   *   The file path.
   */
  public function checkBounce($path) {
    $token = $this->getTokenFromPath($path);

    $bounces = $this->getBounces();
    if (!in_array($token,$bounces)){
      throw new NotFoundHttpException();
    }
  }

  /**
   * Return bounces.
   *
   * @return array|mixed
   *    The bounces.
   */
  public function getBounces() {
    if (is_null($this->bounces)) {
      $this->bounces = $this->state->get(static::STATE_ID) ?? [];
    }
    return $this->bounces;
  }

  /**
   * Delete state.
   */
  public function cleanBounce() {
    $this->state->delete(static::STATE_ID);
  }

}

==> media_twig_tools-2.1.0-rc3.tar.gz: media_twig_tools/src/Services/Bounce.php <==
<?php

namespace Drupal\media_twig_tools\Services;

use Drupal\Core\State\StateInterface;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Service description.
 */
class Bounce {

  /**
   * Service ID.
   *
   * @const string
   */
  public const SERVICE_ID = 'media_twig_tools.bounce';

  /**
   * State id.
   *
   * @const string
   */
  public const STATE_ID = 'media_twig_tools.bounce';

  /**
   * Singleton quick access.
   *
   * @return static
   *   Singleton.
   */
  public static function instance() {
    return \Drupal::service(static::SERVICE_ID);
  }

  /**
   * The state.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected StateInterface $state;

  /**
   * Bounces.
   *
   * @var array
   */
  protected ?array $bounces;

  /**
   * Dirname.
   *
   * @var string
   */
  protected ?string $dirname;

  /**
   * Constructs a Bounce object.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The state.
   */
  public function __construct(StateInterface $state) {
    $this->state = $state;
  }

  /**
   * Return the dirname.
   *
   * @return string
   *   The dirname.
   */
  public function getDirname(): string {
    return $this->dirname;
  }

  /**
   * Set the dirname.
   *
   * @param string $dirname
   *   The dirname.
   */
  public function setDirname(string $dirname): void {
    $this->dirname = $dirname;
  }

  /**
   * Add the bounce in config.
   *
   * @param string $path
   *   The path.
   */
  public function addBounce(string $path) {
    $token = $this->getTokenFromPath($path);
    $bounces = $this->getBounces();
    if (!in_array($token, $bounces)) {
      $this->bounces[] = $token;
      $this->state->set(static::STATE_ID, $this->bounces);
    }
  }

  /**
   * Return token from path.
   *
   * @param string $path
   *   The file path.
   *
   * @return string
   *   The path.
   */
  public function getTokenFromPath(string $path) {
    $token = explode($this->getDirname(), $path);
    $token = end($token);
    $token = array_filter(explode('/', $token));
    return implode('/', array_slice($token, 0, -1));
  }

  /**
   * Check the bounce.
   *
   * @param string $path
   *   The file path.
   */
  public function checkBounce($path) {
    $token = $this->getTokenFromPath($path);

    $bounces = $this->getBounces();
    if (!in_array($token, $bounces)) {
      throw new NotFoundHttpException();
    }
  }

  /**
   * Return bounces.
   *
   * @return array|mixed
   *   The bounces.
   */
  public function getBounces() {
    if (!isset($this->bounces)) {
      $this->bounces = $this->state->get(static::STATE_ID) ?? [];
    }
    return $this->bounces;
  }

  /**
   * Delete state.
   */
  public function cleanBounce() {
    $this->state->delete(static::STATE_ID);
  }

}
